Nagare Examples Changelog
=========================

0.3.1
-----

- Project only hosted on Github now
- Documentation served as github.io pages
- Nagare 0.5

0.3.0
-----

New features
~~~~~~~~~~~~

- Mercurial migration
- new site, examples and documentation design

Changes
~~~~~~~

- A renderer can create an asynchronous renderer:
  ``comp.render(xhtml.AsyncRenderer())`` => ``comp.render(h.AsyncRenderer())``
- unused examples removed

Fixed bugs
~~~~~~~~~~

- #69: missing files


0.2.0
-----

New features
~~~~~~~~~~~~

- ``jewels`` game example added
- ``chat`` comet Chat example added


0.1.0
-----

Initial release
